@@ -1,13 +1,19 @@
 import time
 from pathlib import Path
 
-from . import byte_translate, icon_manager
+from . import byte_translate, icon_manager, url
 from .icon import Icon
 
 
 class File:
     def __init__(self, path: Path):
-        self.path = path
+        if path.suffix == 'url':
+            self.path = path.stem
+            self.is_url = True
+            self.url = url.get_url_from_path(path)
+        else:
+            self.path = path
+            self.is_url = False
 
     def __str__(self):
         return self.path.__str__()
@@ -32,7 +38,9 @@ class File:
 
     @property
     def size(self) -> str:
-        if self.is_dir:
+        if self.is_url:
+            size = 0
+        elif self.is_dir:
             size = sum(f.stat().st_size for f in self.path.rglob('*') if f.is_file())
         else:
             size = self.path.stat().st_size
@@ -41,10 +49,19 @@ class File:
 
     @property
     def modified(self):
+        if self.is_url:
+            return '-'
+
         return time.ctime(self.path.stat().st_mtime)
 
+    def __replace_filename(self, template: str, key: str) -> str:
+        if self.is_url:
+            return template.replace(key, self.url)
+        else:
+            return template.replace(key, self.filename)
+
     def to_html(self, template: str) -> str:
-        return template.replace('#FILENAME', self.filename) \
+        return self.__replace_filename(template, '#FILENAME') \
             .replace('#ICON', self.icon.relative_path.as_posix()) \
             .replace('#SIZE', self.size) \
             .replace('#MODIFIED', self.modified)
